<?php
/**
 * Theme Palace options
 *
 * @package Theme Palace
 * @subpackage Educollege Pro
 * @since Educollege Pro 1.0.0
 */

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function educollege_pro_page_choices() {
    $pages = get_pages();
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $pages as $page ) {
        $choices[ $page->ID ] = $page->post_title;
    }
    return  $choices;
}

/**
 * List of posts for post choices.
 * @return Array Array of post ids and name.
 */
function educollege_pro_post_choices() {
    $posts = get_posts( array( 'numberposts' => -1 ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $posts as $post ) {
        $choices[ $post->ID ] = $post->post_title;
    }
    return  $choices;
}

/**
 * List of posts for course choices.
 * @return Array Array of course ids and name.
 */
function educollege_pro_course_choices() {
    $courses = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-course' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $courses as $course ) {
        $choices[ $course->ID ] = $course->post_title;
    }
    return  $choices;
}

/**
 * List of posts for course choices.
 * @return Array Array of course ids and name.
 */
function educollege_pro_event_choices() {
    $events = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-event' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $events as $event ) {
        $choices[ $event->ID ] = $event->post_title;
    }
    return  $choices;
}

/**
 * List of posts for team choices.
 * @return Array Array of team ids and name.
 */
function educollege_pro_team_choices() {
    $teams = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-team' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $teams as $team ) {
        $choices[ $team->ID ] = $team->post_title;
    }
    return  $choices;
}

/**
 * List of pages for page choices.
 * @return Array Array of page ids and name.
 */
function educollege_pro_testimonial_choices() {
    $testimonials = get_posts( array( 'numberposts' => -1, 'post_type'=>'tp-testimonial' ) );
    $choices = array();
    $choices[0] = esc_html__( '--Select--', 'educollege-pro' );
    foreach ( $testimonials as $testimonial ) {
        $choices[ $testimonial->ID ] = $testimonial->post_title;
    }
    return  $choices;
}

if ( ! function_exists( 'educollege_pro_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function educollege_pro_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'educollege-pro' ),
            'header-font-1'   => esc_html__( 'Rajdhani', 'educollege-pro' ),
            'header-font-2'   => esc_html__( 'Cherry Swash', 'educollege-pro' ),
            'header-font-3'   => esc_html__( 'Philosopher', 'educollege-pro' ),
            'header-font-4'   => esc_html__( 'Slabo 27px', 'educollege-pro' ),
            'header-font-5'   => esc_html__( 'Dosis', 'educollege-pro' ),
        );

        $output = apply_filters( 'educollege_pro_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_body_typography_options' ) ) :
    /**
     * Returns list of typography
     * @return array font styles
     */
    function educollege_pro_body_typography_options(){
        $choices = array(
            'default'         => esc_html__( 'Default', 'educollege-pro' ),
            'body-font-1'     => esc_html__( 'News Cycle', 'educollege-pro' ),
            'body-font-2'     => esc_html__( 'Pontano Sans', 'educollege-pro' ),
            'body-font-3'     => esc_html__( 'Gudea', 'educollege-pro' ),
            'body-font-4'     => esc_html__( 'Quattrocento', 'educollege-pro' ),
            'body-font-5'     => esc_html__( 'Khand', 'educollege-pro' ),
        );

        $output = apply_filters( 'educollege_pro_body_typography_options', $choices );
        if ( ! empty( $output ) ) {
            ksort( $output );
        }

        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_selected_sidebar' ) ) :
    /**
     * Sidebars options
     * @return array Sidbar positions
     */
    function educollege_pro_selected_sidebar() {
        $educollege_pro_selected_sidebar = array(
            'sidebar-1'             => esc_html__( 'Default Sidebar', 'educollege-pro' ),
            'optional-sidebar'      => esc_html__( 'Optional Sidebar 1', 'educollege-pro' ),
            'optional-sidebar-2'    => esc_html__( 'Optional Sidebar 2', 'educollege-pro' ),
            'optional-sidebar-3'    => esc_html__( 'Optional Sidebar 3', 'educollege-pro' ),
            'optional-sidebar-4'    => esc_html__( 'Optional Sidebar 4', 'educollege-pro' ),
        );

        $output = apply_filters( 'educollege_pro_selected_sidebar', $educollege_pro_selected_sidebar );

        return $output;
    }
endif;

if ( ! function_exists( 'educollege_pro_site_layout' ) ) :
    /**
     * Site Layout
     * @return array site layout options
     */
    function educollege_pro_site_layout() {
        $educollege_pro_site_layout = array(
            'wide-layout'  => get_template_directory_uri() . '/assets/images/full.png',
            'boxed-layout' => get_template_directory_uri() . '/assets/images/boxed.png',
            'frame-layout' => get_template_directory_uri() . '/assets/images/framed.png',
        );

        $output = apply_filters( 'educollege_pro_site_layout', $educollege_pro_site_layout );
        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_global_sidebar_position' ) ) :
    /**
     * Global Sidebar position
     * @return array Global Sidebar positions
     */
    function educollege_pro_global_sidebar_position() {
        $educollege_pro_global_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
        );

        $output = apply_filters( 'educollege_pro_global_sidebar_position', $educollege_pro_global_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_sidebar_position' ) ) :
    /**
     * Sidebar position
     * @return array Sidbar positions
     */
    function educollege_pro_sidebar_position() {
        $educollege_pro_sidebar_position = array(
            'right-sidebar' => get_template_directory_uri() . '/assets/images/right.png',
            'left-sidebar'  => get_template_directory_uri() . '/assets/images/left.png',
            'no-sidebar'    => get_template_directory_uri() . '/assets/images/full.png',
            'no-sidebar-content'   => get_template_directory_uri() . '/assets/images/boxed.png',
        );

        $output = apply_filters( 'educollege_pro_sidebar_position', $educollege_pro_sidebar_position );

        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_pagination_options' ) ) :
    /**
     * Pagination
     * @return array site pagination options
     */
    function educollege_pro_pagination_options() {
        $educollege_pro_pagination_options = array(
            'numeric'   => esc_html__( 'Numeric', 'educollege-pro' ),
            'default'   => esc_html__( 'Default(Older/Newer)', 'educollege-pro' ),
            'infinite'  => esc_html__( 'Infinite', 'educollege-pro' ),
        );

        $output = apply_filters( 'educollege_pro_pagination_options', $educollege_pro_pagination_options );

        return $output;
    }
endif;

if ( ! function_exists( 'educollege_pro_get_spinner_list' ) ) :
    /**
     * List of spinner icons options.
     * @return array List of all spinner icon options.
     */
    function educollege_pro_get_spinner_list() {
        $arr = array(
            'default'               => esc_html__( 'Default', 'educollege-pro' ),
            'spinner-wheel'         => esc_html__( 'Wheel', 'educollege-pro' ),
            'spinner-double-circle' => esc_html__( 'Double Circle', 'educollege-pro' ),
            'spinner-two-way'       => esc_html__( 'Two Way', 'educollege-pro' ),
            'spinner-umbrella'      => esc_html__( 'Umbrella', 'educollege-pro' ),
            'spinner-dots'          => esc_html__( 'Dots', 'educollege-pro' ),
            'spinner-one-way'       => esc_html__( 'One Way', 'educollege-pro' ),
            'spinner-fidget'        => esc_html__( 'Fidget', 'educollege-pro' ),
        );
        return apply_filters( 'educollege_pro_spinner_list', $arr );
    }
endif;

if ( ! function_exists( 'educollege_pro_switch_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function educollege_pro_switch_options() {
        $arr = array(
            'on'        => esc_html__( 'Enable', 'educollege-pro' ),
            'off'       => esc_html__( 'Disable', 'educollege-pro' )
        );
        return apply_filters( 'educollege_pro_switch_options', $arr );
    }
endif;

if ( ! function_exists( 'educollege_pro_hide_options' ) ) :
    /**
     * List of custom Switch Control options
     * @return array List of switch control options.
     */
    function educollege_pro_hide_options() {
        $arr = array(
            'on'        => esc_html__( 'Yes', 'educollege-pro' ),
            'off'       => esc_html__( 'No', 'educollege-pro' )
        );
        return apply_filters( 'educollege_pro_hide_options', $arr );
    }
endif;

if ( ! function_exists( 'educollege_pro_sortable_sections' ) ) :
    /**
     * List of sections Control options
     * @return array List of Sections control options.
     */
    function educollege_pro_sortable_sections() {
        $sections = array(
            'slider'                => esc_html__( 'Main Slider', 'educollege-pro' ),
            'featured'              => esc_html__( 'Featured Section', 'educollege-pro' ),
            'service'               => esc_html__( 'Service Section', 'educollege-pro' ),
            'about'                 => esc_html__( 'About Section', 'educollege-pro' ),
            'course'                => esc_html__( 'Course Section', 'educollege-pro' ),
            'reason'                => esc_html__( 'Reason Section', 'educollege-pro' ),
            'cta'                   => esc_html__( 'Call to Action Section', 'educollege-pro' ),
            'team'                  => esc_html__( 'Team Section', 'educollege-pro' ),
            'blog'                  => esc_html__( 'Blog Section', 'educollege-pro' ),
            'counter'               => esc_html__( 'Counter Section', 'educollege-pro' ),
            'testimonial'           => esc_html__( 'Testimonial Section', 'educollege-pro' ),
            'client'                => esc_html__( 'Client Section', 'educollege-pro' ),
        );
        return apply_filters( 'educollege_pro_sortable_sections', $sections );
    }
endif;

if ( ! function_exists( 'educollege_pro_popular_course_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function educollege_pro_popular_course_content_type() {
        $educollege_pro_popular_course_content_type = array(
            'page'      => esc_html__( 'Page', 'educollege-pro' ),
            'post'      => esc_html__( 'Post', 'educollege-pro' ),
            'category'  => esc_html__( 'Category', 'educollege-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $educollege_pro_popular_course_content_type_plugin = array();

            if ( post_type_exists( 'tp-course' ) ) {
                $educollege_pro_popular_course_content_type_plugin['course'] = esc_html__('Course', 'educollege-pro');
                $educollege_pro_popular_course_content_type_plugin['course-category'] = esc_html__('Course Category', 'educollege-pro');
            }
        }
         if ( !class_exists('TP_Education')) {
            $educollege_pro_popular_course_content_type_plugin = array();
        }
        $educollege_pro_popular_course_content_type = array_merge( $educollege_pro_popular_course_content_type, $educollege_pro_popular_course_content_type_plugin );
        $output = apply_filters( 'educollege_pro_popular_course_content_type', $educollege_pro_popular_course_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'educollege_pro_popular_team_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function educollege_pro_popular_team_content_type() {
        $educollege_pro_popular_team_content_type = array(
            'page'      => esc_html__( 'Page', 'educollege-pro' ),
            'post'      => esc_html__( 'Post', 'educollege-pro' ),
            'category'  => esc_html__( 'Category', 'educollege-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $custom_choices = array();
            if ( post_type_exists( 'tp-team' ) ) {
               $custom_choices['tp-team']   =  esc_html__( 'Team', 'educollege-pro' );
               $custom_choices['tp-team-category']   =  esc_html__( 'Team Category', 'educollege-pro' );    
            }
        }
        if ( !class_exists('TP_Education')) {
            $custom_choices = array();
        }
        $educollege_pro_popular_team_content_type = array_merge( $educollege_pro_popular_team_content_type, $custom_choices );
        $output = apply_filters( 'educollege_pro_popular_team_content_type', $educollege_pro_popular_team_content_type );


        return $output;
    }
endif;

if ( ! function_exists( 'educollege_pro_popular_event_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function educollege_pro_popular_event_content_type() {
        $educollege_pro_popular_event_content_type = array(
                'page'      => esc_html__( 'Page', 'educollege-pro' ),
                'post'      => esc_html__( 'Post', 'educollege-pro' ),
                'category'  => esc_html__( 'Category', 'educollege-pro' ),
            ) ;
        if ( class_exists( 'TP_Education' ) ) {
            $educollege_pro_popular_event_content_type = array_merge($educollege_pro_popular_event_content_type, array(
                'event'            => esc_html__( 'Event', 'educollege-pro' ),
                'event-category'   => esc_html__( 'Event Category', 'educollege-pro' ),
                ) );
        }
       
        $output = apply_filters( 'educollege_pro_popular_event_content_type', $educollege_pro_popular_event_content_type );


        return $output;
    }
endif;


if ( ! function_exists( 'educollege_pro_testimonial_content_type' ) ) :
    /**
     * Destination Options
     * @return array site gallery options
     */
    function educollege_pro_testimonial_content_type() {
        $educollege_pro_testimonial_content_type = array(
            'page'      => esc_html__( 'Page', 'educollege-pro' ),
            'post'      => esc_html__( 'Post', 'educollege-pro' ),
            'custom'  => esc_html__( 'Custom', 'educollege-pro' ),
        );

        if ( class_exists( 'TP_Education' ) ) {
            $custom_choices = array();
            if ( post_type_exists( 'tp-testimonial' ) ) {
                $custom_choices['tp-testimonial'] = esc_html__( 'Testimonial', 'educollege-pro' );
            }
        }
        if ( ! class_exists('TP_Education') ) {
            $custom_choices = array();
        }
        $educollege_pro_testimonial_content_type = array_merge( $educollege_pro_testimonial_content_type, $custom_choices );
        $output = apply_filters( 'educollege_pro_testimonial_content_type', $educollege_pro_testimonial_content_type );


        return $output;
    }
endif;

